@@ -1,8 +1,7 @@
-import argparse
 import os
 import sys
 
-from . import commands
+from . import arguments, commands
 from . import git_utils
 from . import mkdocs_utils
 from .app_version import version as app_version
@@ -60,7 +59,7 @@ def add_git_arguments(parser, *, commit=True, prefix=True):
     # Add this whenever we add git arguments since we pull the remote and
     # branch from mkdocs.yml.
     parser.add_argument('-F', '--config-file', metavar='FILE',
-                        default='mkdocs.yml',
+                        default='mkdocs.yml', complete='file',
                         help='the MkDocs configuration file to use')
 
     git = parser.add_argument_group('git arguments')
@@ -78,6 +77,7 @@ def add_git_arguments(parser, *, commit=True, prefix=True):
 
     if prefix:
         git.add_argument('--prefix', metavar='PATH', default='',
+                         complete='directory',
                          help=('subdirectory within {branch} where docs are ' +
                                'located'))
 
@@ -227,7 +227,7 @@ def generate_completion(parser, args):
 
 
 def main():
-    parser = argparse.ArgumentParser(prog='mike', description=description)
+    parser = arguments.ArgumentParser(prog='mike', description=description)
     subparsers = parser.add_subparsers(metavar='COMMAND')
     subparsers.required = True
 
@@ -246,7 +246,7 @@ def main():
     deploy_p.add_argument('--no-redirect', dest='redirect', default=True,
                           action='store_false',
                           help='make copies of docs for each alias')
-    deploy_p.add_argument('-T', '--template',
+    deploy_p.add_argument('-T', '--template', complete='file',
                           help='the template file to use for redirects')
     add_git_arguments(deploy_p)
     deploy_p.add_argument('version', metavar='VERSION',
@@ -273,7 +273,7 @@ def main():
     alias_p.add_argument('--no-redirect', dest='redirect', default=True,
                          action='store_false',
                          help='make copies of docs for each alias')
-    alias_p.add_argument('-T', '--template',
+    alias_p.add_argument('-T', '--template', complete='file',
                          help='the template file to use for redirects')
     add_git_arguments(alias_p)
     alias_p.add_argument('version', metavar='VERSION',
@@ -307,7 +307,7 @@ def main():
         help='set the default version for your docs'
     )
     set_default_p.set_defaults(func=set_default)
-    set_default_p.add_argument('-T', '--template',
+    set_default_p.add_argument('-T', '--template', complete='file',
                                help='the template file to use')
     add_git_arguments(set_default_p)
     set_default_p.add_argument('version', metavar='VERSION',
@@ -327,7 +327,7 @@ def main():
         'help', help='show this help message and exit', add_help=False
     )
     help_p.set_defaults(func=help)
-    help_p.add_argument('subcommand', metavar='CMD', nargs=argparse.REMAINDER,
+    help_p.add_argument('subcommand', metavar='CMD', nargs=arguments.REMAINDER,
                         help='subcommand to request help for')
 
     completion_p = subparsers.add_parser(
